@@ -162,6 +162,8 @@ warn = findIndices ((==) a) ==> elemIndices a
 warn = findIndices (a ==) ==> elemIndices a
 warn = findIndices (== a) ==> elemIndices a
 warn = lookup b (zip l [0..]) ==> elemIndex b l
+hint = elem x [y] ==> x == y where note = ValidInstance "Eq" a
+hint = notElem x [y] ==> x /= y where note = ValidInstance "Eq" a
 hint "Length always non-negative" = length x >= 0 ==> True
 hint "Use null" = length x > 0 ==> not (null x) where note = IncreasesLaziness
 hint "Use null" = length x >= 1 ==> not (null x) where note = IncreasesLaziness
@@ -225,7 +227,6 @@ warn "Redundant $" = (($) . f) ==> f
 warn "Redundant $" = (f $) ==> f
 hint = (\x -> y) ==> const y where _ = isAtom y && not (isWildcard y)
 warn "Redundant flip" = flip f x y ==> f y x where _ = isApp original
-hint = (\a b -> g (f a) (f b)) ==> g `Data.Function.on` f
 warn "Evaluate" = id x ==> x
 warn "Redundant id" = id . x ==> x
 warn "Redundant id" = x . id ==> x
@@ -374,6 +375,7 @@ hint "Redundant list comprehension" = [x | x <- y] ==> y where _ = isVar x
 -- SEQ
 
 warn "Redundant seq" = x `seq` x ==> x
+warn "Redundant seq" = join seq ==> id
 warn "Redundant $!" = id $! x ==> x
 warn "Redundant seq" = x `seq` y ==> y where _ = isWHNF x
 warn "Redundant $!" = f $! x ==> f x where _ = isWHNF x
@@ -399,7 +401,7 @@ warn = x /= Nothing  ==>  Data.Maybe.isJust x
 warn = Nothing /= x  ==>  Data.Maybe.isJust x
 warn = concatMap (maybeToList . f) ==> Data.Maybe.mapMaybe f
 warn = concatMap maybeToList ==> catMaybes
-warn = maybe n Just x ==> Control.Monad.mplus x n
+warn = maybe n Just x ==> x Control.Applicative.<|> n
 hint = (case x of Just a -> a; Nothing -> y)  ==> fromMaybe y x
 warn = (if isNothing x then y else fromJust x) ==> fromMaybe y x
 warn = (if isJust x then fromJust x else y) ==> fromMaybe y x
